TuulResource class

Constructors

TuulResource({required String id, String? name, String? url, String? type, JsonMap raw = const {}})
const
TuulResource.fromJson(JsonMap json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
name String?
final
raw JsonMap
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
final
url String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited